# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class ActivityEventsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_activity_event(self, **kwargs):  # noqa: E501
        """Create an activity event  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_event(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventCreateRequest body: Activity event create request
        :return: ActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_activity_event_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_activity_event_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_activity_event_with_http_info(self, **kwargs):  # noqa: E501
        """Create an activity event  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_event_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventCreateRequest body: Activity event create request
        :return: ActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_activity_event" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_activity_event_category_relationship(self, **kwargs):  # noqa: E501
        """Create an activity event category relationship  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_event_category_relationship(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventCategoryRelationshipCreateRequest body: Activity event category relationship create request
        :return: ActivityEventCategoryRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_activity_event_category_relationship_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_activity_event_category_relationship_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_activity_event_category_relationship_with_http_info(self, **kwargs):  # noqa: E501
        """Create an activity event category relationship  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_event_category_relationship_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventCategoryRelationshipCreateRequest body: Activity event category relationship create request
        :return: ActivityEventCategoryRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_activity_event_category_relationship" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/CategoryRelationships', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventCategoryRelationshipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_activity_event_relationship(self, **kwargs):  # noqa: E501
        """Create an activity event relationship  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_event_relationship(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventRelationshipCreateRequest body: Activity event relationship create request
        :return: ActivityEventRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_activity_event_relationship_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_activity_event_relationship_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_activity_event_relationship_with_http_info(self, **kwargs):  # noqa: E501
        """Create an activity event relationship  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_activity_event_relationship_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventRelationshipCreateRequest body: Activity event relationship create request
        :return: ActivityEventRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_activity_event_relationship" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Relationships', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventRelationshipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_activity_event(self, activity_event_id, **kwargs):  # noqa: E501
        """Delete an activity event  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity_event(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of the activity event (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_activity_event_with_http_info(activity_event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_activity_event_with_http_info(activity_event_id, **kwargs)  # noqa: E501
            return data

    def delete_activity_event_with_http_info(self, activity_event_id, **kwargs):  # noqa: E501
        """Delete an activity event  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity_event_with_http_info(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of the activity event (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_activity_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_id' is set
        if ('activity_event_id' not in params or
                params['activity_event_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_id` when calling `delete_activity_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_id' in params:
            path_params['activityEventId'] = params['activity_event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/{activityEventId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_activity_event_category_relationship(self, activity_event_category_relationship_id, **kwargs):  # noqa: E501
        """Delete an activity event category relationship  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity_event_category_relationship(activity_event_category_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_category_relationship_id: Id of the activity event category relationship (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_activity_event_category_relationship_with_http_info(activity_event_category_relationship_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_activity_event_category_relationship_with_http_info(activity_event_category_relationship_id, **kwargs)  # noqa: E501
            return data

    def delete_activity_event_category_relationship_with_http_info(self, activity_event_category_relationship_id, **kwargs):  # noqa: E501
        """Delete an activity event category relationship  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity_event_category_relationship_with_http_info(activity_event_category_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_category_relationship_id: Id of the activity event category relationship (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_category_relationship_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_activity_event_category_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_category_relationship_id' is set
        if ('activity_event_category_relationship_id' not in params or
                params['activity_event_category_relationship_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_category_relationship_id` when calling `delete_activity_event_category_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_category_relationship_id' in params:
            path_params['activityEventCategoryRelationshipId'] = params['activity_event_category_relationship_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/CategoryRelationships/{activityEventCategoryRelationshipId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_activity_event_relationship(self, activity_event_relationship_id, **kwargs):  # noqa: E501
        """Delete an activity event relationship  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity_event_relationship(activity_event_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_relationship_id: Id of the activity event relationship (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_activity_event_relationship_with_http_info(activity_event_relationship_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_activity_event_relationship_with_http_info(activity_event_relationship_id, **kwargs)  # noqa: E501
            return data

    def delete_activity_event_relationship_with_http_info(self, activity_event_relationship_id, **kwargs):  # noqa: E501
        """Delete an activity event relationship  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_activity_event_relationship_with_http_info(activity_event_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_relationship_id: Id of the activity event relationship (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_relationship_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_activity_event_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_relationship_id' is set
        if ('activity_event_relationship_id' not in params or
                params['activity_event_relationship_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_relationship_id` when calling `delete_activity_event_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_relationship_id' in params:
            path_params['activityEventRelationshipId'] = params['activity_event_relationship_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Relationships/{activityEventRelationshipId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event(self, activity_event_id, **kwargs):  # noqa: E501
        """Gets an activity event  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of activity event to return (required)
        :return: ActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_with_http_info(activity_event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_with_http_info(activity_event_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_with_http_info(self, activity_event_id, **kwargs):  # noqa: E501
        """Gets an activity event  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_with_http_info(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of activity event to return (required)
        :return: ActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_id' is set
        if ('activity_event_id' not in params or
                params['activity_event_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_id` when calling `get_activity_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_id' in params:
            path_params['activityEventId'] = params['activity_event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/{activityEventId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_categories(self, **kwargs):  # noqa: E501
        """Gets activity event categories  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_categories(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ActivityLineEnabled` | Boolean | `eq, neq` | | `AssetCardEnabled` | Boolean | `eq, neq` | | `CategoryFlag` | ActivityEventCategoryFlag? | `eq, neq, in, isnull, isnotnull` | | `Code` | String | `eq, neq, in, like, isnull, isnotnull` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `Internal` | Boolean | `eq, neq` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `Owner` | ActivityEventCategoryOwnerChild | `isnull, isnotnull` | | `OwnerType` | ActivityEventOwnerType | `eq, neq, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Code` | String | | `Description` | String | | `Name` | String |
        :return: PagedResultsModelActivityEventCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_categories_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_categories_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_activity_event_categories_with_http_info(self, **kwargs):  # noqa: E501
        """Gets activity event categories  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_categories_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ActivityLineEnabled` | Boolean | `eq, neq` | | `AssetCardEnabled` | Boolean | `eq, neq` | | `CategoryFlag` | ActivityEventCategoryFlag? | `eq, neq, in, isnull, isnotnull` | | `Code` | String | `eq, neq, in, like, isnull, isnotnull` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `Internal` | Boolean | `eq, neq` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `Owner` | ActivityEventCategoryOwnerChild | `isnull, isnotnull` | | `OwnerType` | ActivityEventOwnerType | `eq, neq, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Code` | String | | `Description` | String | | `Name` | String |
        :return: PagedResultsModelActivityEventCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_categories" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Categories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelActivityEventCategoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_category(self, activity_event_category_id, **kwargs):  # noqa: E501
        """Gets an activity event category  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_category(activity_event_category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int activity_event_category_id: Id of activity event category to return (required)
        :return: ActivityEventCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_category_with_http_info(activity_event_category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_category_with_http_info(activity_event_category_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_category_with_http_info(self, activity_event_category_id, **kwargs):  # noqa: E501
        """Gets an activity event category  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_category_with_http_info(activity_event_category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int activity_event_category_id: Id of activity event category to return (required)
        :return: ActivityEventCategoryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_category_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_category" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_category_id' is set
        if ('activity_event_category_id' not in params or
                params['activity_event_category_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_category_id` when calling `get_activity_event_category`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_category_id' in params:
            path_params['activityEventCategoryId'] = params['activity_event_category_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Categories/{activityEventCategoryId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventCategoryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_category_fields(self, activity_event_category_id, **kwargs):  # noqa: E501
        """Get activity event category fields  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_category_fields(activity_event_category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int activity_event_category_id: Id of the activity event category (required)
        :return: list[ActivityEventFieldResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_category_fields_with_http_info(activity_event_category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_category_fields_with_http_info(activity_event_category_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_category_fields_with_http_info(self, activity_event_category_id, **kwargs):  # noqa: E501
        """Get activity event category fields  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_category_fields_with_http_info(activity_event_category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int activity_event_category_id: Id of the activity event category (required)
        :return: list[ActivityEventFieldResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_category_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_category_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_category_id' is set
        if ('activity_event_category_id' not in params or
                params['activity_event_category_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_category_id` when calling `get_activity_event_category_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_category_id' in params:
            path_params['activityEventCategoryId'] = params['activity_event_category_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Categories/{activityEventCategoryId}/fields', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ActivityEventFieldResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_category_relationship(self, activity_event_category_relationship_id, **kwargs):  # noqa: E501
        """Gets an activity event category relationship  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_category_relationship(activity_event_category_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_category_relationship_id: Id of activity event category relationship to return (required)
        :return: ActivityEventCategoryRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_category_relationship_with_http_info(activity_event_category_relationship_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_category_relationship_with_http_info(activity_event_category_relationship_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_category_relationship_with_http_info(self, activity_event_category_relationship_id, **kwargs):  # noqa: E501
        """Gets an activity event category relationship  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_category_relationship_with_http_info(activity_event_category_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_category_relationship_id: Id of activity event category relationship to return (required)
        :return: ActivityEventCategoryRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_category_relationship_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_category_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_category_relationship_id' is set
        if ('activity_event_category_relationship_id' not in params or
                params['activity_event_category_relationship_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_category_relationship_id` when calling `get_activity_event_category_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_category_relationship_id' in params:
            path_params['activityEventCategoryRelationshipId'] = params['activity_event_category_relationship_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/CategoryRelationships/{activityEventCategoryRelationshipId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventCategoryRelationshipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_detail(self, activity_event_id, **kwargs):  # noqa: E501
        """Gets an activity event details. Expands on standard get activity event (by id) method  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_detail(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of activity event to return (required)
        :return: ActivityEventDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_detail_with_http_info(activity_event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_detail_with_http_info(activity_event_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_detail_with_http_info(self, activity_event_id, **kwargs):  # noqa: E501
        """Gets an activity event details. Expands on standard get activity event (by id) method  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_detail_with_http_info(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of activity event to return (required)
        :return: ActivityEventDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_detail" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_id' is set
        if ('activity_event_id' not in params or
                params['activity_event_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_id` when calling `get_activity_event_detail`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_id' in params:
            path_params['activityEventId'] = params['activity_event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/{activityEventId}/details', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventDetailResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_field_values(self, activity_event_field_id, **kwargs):  # noqa: E501
        """Get activity event field values (if any)  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_field_values(activity_event_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_field_id: Id of the activity event field (required)
        :param ActivityEventBindType bind_type: Optional bind type.
        :param str bind_id: Optional bind id (requires bind type).
        :param bool allow_query_fallback: Allow query fallback if no matches for bind type / bind id
        :return: list[ActivityEventFieldValueResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_field_values_with_http_info(activity_event_field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_field_values_with_http_info(activity_event_field_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_field_values_with_http_info(self, activity_event_field_id, **kwargs):  # noqa: E501
        """Get activity event field values (if any)  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_field_values_with_http_info(activity_event_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_field_id: Id of the activity event field (required)
        :param ActivityEventBindType bind_type: Optional bind type.
        :param str bind_id: Optional bind id (requires bind type).
        :param bool allow_query_fallback: Allow query fallback if no matches for bind type / bind id
        :return: list[ActivityEventFieldValueResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_field_id', 'bind_type', 'bind_id', 'allow_query_fallback']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_field_values" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_field_id' is set
        if ('activity_event_field_id' not in params or
                params['activity_event_field_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_field_id` when calling `get_activity_event_field_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_field_id' in params:
            path_params['activityEventFieldId'] = params['activity_event_field_id']  # noqa: E501

        query_params = []
        if 'bind_type' in params:
            query_params.append(('bindType', params['bind_type']))  # noqa: E501
        if 'bind_id' in params:
            query_params.append(('bindId', params['bind_id']))  # noqa: E501
        if 'allow_query_fallback' in params:
            query_params.append(('allowQueryFallback', params['allow_query_fallback']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Fields/{activityEventFieldId}/values', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ActivityEventFieldValueResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_relationship(self, activity_event_relationship_id, **kwargs):  # noqa: E501
        """Gets an activity event relationship  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_relationship(activity_event_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_relationship_id: Id of activity event relationship to return (required)
        :return: ActivityEventRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_relationship_with_http_info(activity_event_relationship_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_relationship_with_http_info(activity_event_relationship_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_relationship_with_http_info(self, activity_event_relationship_id, **kwargs):  # noqa: E501
        """Gets an activity event relationship  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_relationship_with_http_info(activity_event_relationship_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_relationship_id: Id of activity event relationship to return (required)
        :return: ActivityEventRelationshipResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_relationship_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_relationship" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_relationship_id' is set
        if ('activity_event_relationship_id' not in params or
                params['activity_event_relationship_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_relationship_id` when calling `get_activity_event_relationship`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_relationship_id' in params:
            path_params['activityEventRelationshipId'] = params['activity_event_relationship_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Relationships/{activityEventRelationshipId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventRelationshipResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_event_subcategories(self, activity_event_category_id, **kwargs):  # noqa: E501
        """Get activity event subcategories  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_subcategories(activity_event_category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int activity_event_category_id: Id of parent activity event category (required)
        :param str location_id: Optional location id
        :return: list[ActivityEventSubcategoryResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_event_subcategories_with_http_info(activity_event_category_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_event_subcategories_with_http_info(activity_event_category_id, **kwargs)  # noqa: E501
            return data

    def get_activity_event_subcategories_with_http_info(self, activity_event_category_id, **kwargs):  # noqa: E501
        """Get activity event subcategories  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_event_subcategories_with_http_info(activity_event_category_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int activity_event_category_id: Id of parent activity event category (required)
        :param str location_id: Optional location id
        :return: list[ActivityEventSubcategoryResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_category_id', 'location_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_event_subcategories" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_category_id' is set
        if ('activity_event_category_id' not in params or
                params['activity_event_category_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_category_id` when calling `get_activity_event_subcategories`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_category_id' in params:
            path_params['activityEventCategoryId'] = params['activity_event_category_id']  # noqa: E501

        query_params = []
        if 'location_id' in params:
            query_params.append(('locationId', params['location_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Categories/{activityEventCategoryId}/subcategories', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ActivityEventSubcategoryResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_activity_events(self, **kwargs):  # noqa: E501
        """Gets activity events  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_events(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ActivityLineEnabled` | Boolean | `eq, neq` | | `AssetCardEnabled` | Boolean | `eq, neq` | | `BindId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `BindType` | ActivityEventBindType? | `eq, neq, in, isnull, isnotnull` | | `CategoryCode` | String | `eq, neq, in, like, isnull, isnotnull` | | `CategoryFlag` | ActivityEventCategoryFlag? | `eq, neq, in, isnull, isnotnull` | | `CategoryId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `CategoryOwnerType` | ActivityEventOwnerType? | `eq, neq, in, isnull, isnotnull` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `EndDateTime` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `FieldCode` | String | `eq, neq, in, like, isnull, isnotnull` | | `FieldId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `FieldType` | ActivityEventFieldType? | `eq, neq, in, isnull, isnotnull` | | `FieldValue` | String | `eq, neq, in, like, isnull, isnotnull` | | `LocationAbbreviation` | String | `eq, neq, in, like, isnull, isnotnull` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Note` | String | `eq, neq, in, like, isnull, isnotnull` | | `RelationshipFromId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `RelationshipToId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `RelationshipType` | ActivityEventRelationshipType? | `eq, neq, in, isnull, isnotnull` | | `StartDateTime` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `SubcategoryCode` | String | `eq, neq, in, like, isnull, isnotnull` | | `SubcategoryId` | Guid | `eq, neq, in` | | `Title` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Description` | String | | `EndDateTime` | DateTime? | | `LocationName` | String | | `Note` | String | | `StartDateTime` | DateTime | | `Title` | String |
        :return: PagedResultsModelActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_activity_events_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_activity_events_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_activity_events_with_http_info(self, **kwargs):  # noqa: E501
        """Gets activity events  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_activity_events_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ActivityLineEnabled` | Boolean | `eq, neq` | | `AssetCardEnabled` | Boolean | `eq, neq` | | `BindId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `BindType` | ActivityEventBindType? | `eq, neq, in, isnull, isnotnull` | | `CategoryCode` | String | `eq, neq, in, like, isnull, isnotnull` | | `CategoryFlag` | ActivityEventCategoryFlag? | `eq, neq, in, isnull, isnotnull` | | `CategoryId` | Int32 | `eq, neq, in, lt, gt, leq, geq` | | `CategoryOwnerType` | ActivityEventOwnerType? | `eq, neq, in, isnull, isnotnull` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `EndDateTime` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `FieldCode` | String | `eq, neq, in, like, isnull, isnotnull` | | `FieldId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `FieldType` | ActivityEventFieldType? | `eq, neq, in, isnull, isnotnull` | | `FieldValue` | String | `eq, neq, in, like, isnull, isnotnull` | | `LocationAbbreviation` | String | `eq, neq, in, like, isnull, isnotnull` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Note` | String | `eq, neq, in, like, isnull, isnotnull` | | `RelationshipFromId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `RelationshipToId` | Guid? | `eq, neq, in, isnull, isnotnull` | | `RelationshipType` | ActivityEventRelationshipType? | `eq, neq, in, isnull, isnotnull` | | `StartDateTime` | DateTime | `eq, neq, in, lt, gt, leq, geq` | | `SubcategoryCode` | String | `eq, neq, in, like, isnull, isnotnull` | | `SubcategoryId` | Guid | `eq, neq, in` | | `Title` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Description` | String | | `EndDateTime` | DateTime? | | `LocationName` | String | | `Note` | String | | `StartDateTime` | DateTime | | `Title` | String |
        :return: PagedResultsModelActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_activity_events" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelActivityEventResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_hierarchy_activity_events_post(self, **kwargs):  # noqa: E501
        """Gets activity events for hierarchy groups  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hierarchy_activity_events_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventHierarchyGroupRequest body: ActivityEventHierarchyGroupRequest instance
        :param bool is_slim: Set to true for slim (less properties) response list
        :param bool is_export:
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Created` | DateTime? | | `CreatedBy` | String | | `Description` | String | | `EndDateTime` | DateTime? | | `LocationName` | String | | `StartDateTime` | DateTime | | `Title` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `CategoryDescription`, `CreatedBy`, `Description`, `HierarchySearch`, `Title`.
        :return: PagedResultsModelActivityEventHierarchyGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_hierarchy_activity_events_post_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_hierarchy_activity_events_post_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_hierarchy_activity_events_post_with_http_info(self, **kwargs):  # noqa: E501
        """Gets activity events for hierarchy groups  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_hierarchy_activity_events_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ActivityEventHierarchyGroupRequest body: ActivityEventHierarchyGroupRequest instance
        :param bool is_slim: Set to true for slim (less properties) response list
        :param bool is_export:
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Created` | DateTime? | | `CreatedBy` | String | | `Description` | String | | `EndDateTime` | DateTime? | | `LocationName` | String | | `StartDateTime` | DateTime | | `Title` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `CategoryDescription`, `CreatedBy`, `Description`, `HierarchySearch`, `Title`.
        :return: PagedResultsModelActivityEventHierarchyGroupResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'is_slim', 'is_export', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_hierarchy_activity_events_post" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'is_slim' in params:
            query_params.append(('isSlim', params['is_slim']))  # noqa: E501
        if 'is_export' in params:
            query_params.append(('isExport', params['is_export']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/HierarchyGroups', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelActivityEventHierarchyGroupResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_activity_event(self, activity_event_id, **kwargs):  # noqa: E501
        """Update an activity event  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity_event(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of the activity event (required)
        :param ActivityEventUpdateRequest body: Activity event update request
        :return: ActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_activity_event_with_http_info(activity_event_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_activity_event_with_http_info(activity_event_id, **kwargs)  # noqa: E501
            return data

    def update_activity_event_with_http_info(self, activity_event_id, **kwargs):  # noqa: E501
        """Update an activity event  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity_event_with_http_info(activity_event_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_id: Id of the activity event (required)
        :param ActivityEventUpdateRequest body: Activity event update request
        :return: ActivityEventResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_activity_event" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_id' is set
        if ('activity_event_id' not in params or
                params['activity_event_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_id` when calling `update_activity_event`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_id' in params:
            path_params['activityEventId'] = params['activity_event_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/{activityEventId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ActivityEventResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_activity_event_field_values(self, activity_event_field_id, **kwargs):  # noqa: E501
        """Update / replace activity event field values list  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity_event_field_values(activity_event_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_field_id: Id of the activity event field (required)
        :param list[ActivityEventFieldValueRequest] body:
        :param ActivityEventBindType bind_type: Optional bind type.
        :param str bind_id: Optional bind id (requires bind type).
        :return: list[ActivityEventFieldValueResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_activity_event_field_values_with_http_info(activity_event_field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_activity_event_field_values_with_http_info(activity_event_field_id, **kwargs)  # noqa: E501
            return data

    def update_activity_event_field_values_with_http_info(self, activity_event_field_id, **kwargs):  # noqa: E501
        """Update / replace activity event field values list  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_activity_event_field_values_with_http_info(activity_event_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str activity_event_field_id: Id of the activity event field (required)
        :param list[ActivityEventFieldValueRequest] body:
        :param ActivityEventBindType bind_type: Optional bind type.
        :param str bind_id: Optional bind id (requires bind type).
        :return: list[ActivityEventFieldValueResponse]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['activity_event_field_id', 'body', 'bind_type', 'bind_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_activity_event_field_values" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'activity_event_field_id' is set
        if ('activity_event_field_id' not in params or
                params['activity_event_field_id'] is None):
            raise ValueError("Missing the required parameter `activity_event_field_id` when calling `update_activity_event_field_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'activity_event_field_id' in params:
            path_params['activityEventFieldId'] = params['activity_event_field_id']  # noqa: E501

        query_params = []
        if 'bind_type' in params:
            query_params.append(('bindType', params['bind_type']))  # noqa: E501
        if 'bind_id' in params:
            query_params.append(('bindId', params['bind_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/ActivityEvents/Fields/{activityEventFieldId}/values', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ActivityEventFieldValueResponse]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IndicatorBaselineResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'is_damage_accumulation_pressure': 'bool',
        'baseline': 'BaselineWithSignificantDigitsChild',
        'hierarchy': 'list[HierarchyChild]'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'is_damage_accumulation_pressure': 'IsDamageAccumulationPressure',
        'baseline': 'Baseline',
        'hierarchy': 'Hierarchy'
    }

    def __init__(self, id=None, name=None, abbreviation=None, is_damage_accumulation_pressure=None, baseline=None, hierarchy=None):  # noqa: E501
        """IndicatorBaselineResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._abbreviation = None
        self._is_damage_accumulation_pressure = None
        self._baseline = None
        self._hierarchy = None
        self.discriminator = None
        self.id = id
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        self.is_damage_accumulation_pressure = is_damage_accumulation_pressure
        self.baseline = baseline
        self.hierarchy = hierarchy

    @property
    def id(self):
        """Gets the id of this IndicatorBaselineResponse.  # noqa: E501

        The Id of the indicator  # noqa: E501

        :return: The id of this IndicatorBaselineResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IndicatorBaselineResponse.

        The Id of the indicator  # noqa: E501

        :param id: The id of this IndicatorBaselineResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this IndicatorBaselineResponse.  # noqa: E501

        The name of the indicator  # noqa: E501

        :return: The name of this IndicatorBaselineResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndicatorBaselineResponse.

        The name of the indicator  # noqa: E501

        :param name: The name of this IndicatorBaselineResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this IndicatorBaselineResponse.  # noqa: E501

        The abbreviation of the indicator  # noqa: E501

        :return: The abbreviation of this IndicatorBaselineResponse.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this IndicatorBaselineResponse.

        The abbreviation of the indicator  # noqa: E501

        :param abbreviation: The abbreviation of this IndicatorBaselineResponse.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def is_damage_accumulation_pressure(self):
        """Gets the is_damage_accumulation_pressure of this IndicatorBaselineResponse.  # noqa: E501

        Determines whether or not the indicator is of type DamageAccumulationPressure  # noqa: E501

        :return: The is_damage_accumulation_pressure of this IndicatorBaselineResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_damage_accumulation_pressure

    @is_damage_accumulation_pressure.setter
    def is_damage_accumulation_pressure(self, is_damage_accumulation_pressure):
        """Sets the is_damage_accumulation_pressure of this IndicatorBaselineResponse.

        Determines whether or not the indicator is of type DamageAccumulationPressure  # noqa: E501

        :param is_damage_accumulation_pressure: The is_damage_accumulation_pressure of this IndicatorBaselineResponse.  # noqa: E501
        :type: bool
        """
        if is_damage_accumulation_pressure is None:
            raise ValueError("Invalid value for `is_damage_accumulation_pressure`, must not be `None`")  # noqa: E501

        self._is_damage_accumulation_pressure = is_damage_accumulation_pressure

    @property
    def baseline(self):
        """Gets the baseline of this IndicatorBaselineResponse.  # noqa: E501


        :return: The baseline of this IndicatorBaselineResponse.  # noqa: E501
        :rtype: BaselineWithSignificantDigitsChild
        """
        return self._baseline

    @baseline.setter
    def baseline(self, baseline):
        """Sets the baseline of this IndicatorBaselineResponse.


        :param baseline: The baseline of this IndicatorBaselineResponse.  # noqa: E501
        :type: BaselineWithSignificantDigitsChild
        """
        if baseline is None:
            raise ValueError("Invalid value for `baseline`, must not be `None`")  # noqa: E501

        self._baseline = baseline

    @property
    def hierarchy(self):
        """Gets the hierarchy of this IndicatorBaselineResponse.  # noqa: E501

        The list of the parent groups for the indicator  # noqa: E501

        :return: The hierarchy of this IndicatorBaselineResponse.  # noqa: E501
        :rtype: list[HierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this IndicatorBaselineResponse.

        The list of the parent groups for the indicator  # noqa: E501

        :param hierarchy: The hierarchy of this IndicatorBaselineResponse.  # noqa: E501
        :type: list[HierarchyChild]
        """
        if hierarchy is None:
            raise ValueError("Invalid value for `hierarchy`, must not be `None`")  # noqa: E501

        self._hierarchy = hierarchy

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IndicatorBaselineResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorBaselineResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class BulletinsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_bulletin(self, **kwargs):  # noqa: E501
        """Creates a bulletin  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bulletin(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str title:
        :param str description:
        :param str article_url:
        :param datetime start:
        :param datetime end:
        :param bool is_draft:
        :param str image:
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_bulletin_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.create_bulletin_with_http_info(**kwargs)  # noqa: E501
            return data

    def create_bulletin_with_http_info(self, **kwargs):  # noqa: E501
        """Creates a bulletin  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bulletin_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str title:
        :param str description:
        :param str article_url:
        :param datetime start:
        :param datetime end:
        :param bool is_draft:
        :param str image:
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['title', 'description', 'article_url', 'start', 'end', 'is_draft', 'image']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_bulletin" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'title' in params:
            form_params.append(('Title', params['title']))  # noqa: E501
        if 'description' in params:
            form_params.append(('Description', params['description']))  # noqa: E501
        if 'article_url' in params:
            form_params.append(('ArticleUrl', params['article_url']))  # noqa: E501
        if 'start' in params:
            form_params.append(('Start', params['start']))  # noqa: E501
        if 'end' in params:
            form_params.append(('End', params['end']))  # noqa: E501
        if 'is_draft' in params:
            form_params.append(('IsDraft', params['is_draft']))  # noqa: E501
        if 'image' in params:
            local_var_files['image'] = params['image']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Bulletins', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BulletinResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_bulletin(self, id, **kwargs):  # noqa: E501
        """Deletes a bulletin  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bulletin(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_bulletin_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_bulletin_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_bulletin_with_http_info(self, id, **kwargs):  # noqa: E501
        """Deletes a bulletin  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bulletin_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_bulletin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_bulletin`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Bulletins/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bulletin(self, id, **kwargs):  # noqa: E501
        """Gets a specific bulletin  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bulletin(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin (required)
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bulletin_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bulletin_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_bulletin_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets a specific bulletin  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bulletin_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin (required)
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bulletin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_bulletin`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Bulletins/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BulletinResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bulletins(self, **kwargs):  # noqa: E501
        """Gets bulletins  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bulletins(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ArticleUrl` | Uri | `eq, neq, in, isnull, isnotnull` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `End` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `IsDraft` | Boolean | `eq, neq` | | `Start` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `Title` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `ArticleUrl` | Uri | | `Description` | String | | `End` | DateTime? | | `IsDraft` | Boolean | | `Start` | DateTime? | | `Title` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `Title`.
        :return: PagedResultsModelBulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bulletins_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_bulletins_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_bulletins_with_http_info(self, **kwargs):  # noqa: E501
        """Gets bulletins  # noqa: E501

        Required Permissions: User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bulletins_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `ArticleUrl` | Uri | `eq, neq, in, isnull, isnotnull` | | `Description` | String | `eq, neq, in, like, isnull, isnotnull` | | `End` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `IsDraft` | Boolean | `eq, neq` | | `Start` | DateTime? | `eq, neq, in, lt, gt, leq, geq, isnull, isnotnull` | | `Title` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `ArticleUrl` | Uri | | `Description` | String | | `End` | DateTime? | | `IsDraft` | Boolean | | `Start` | DateTime? | | `Title` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `Description`, `Title`.
        :return: PagedResultsModelBulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bulletins" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Bulletins', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelBulletinResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_bulletin(self, id, **kwargs):  # noqa: E501
        """Updates a bulletin  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bulletin(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin (required)
        :param BulletinUpdateRequest body: Request to update the bulletin
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_bulletin_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_bulletin_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_bulletin_with_http_info(self, id, **kwargs):  # noqa: E501
        """Updates a bulletin  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bulletin_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin (required)
        :param BulletinUpdateRequest body: Request to update the bulletin
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_bulletin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_bulletin`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Bulletins/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BulletinResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_bulletin_image(self, id, **kwargs):  # noqa: E501
        """Updates a bulletin's image  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bulletin_image(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin (required)
        :param str image:
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_bulletin_image_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_bulletin_image_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def update_bulletin_image_with_http_info(self, id, **kwargs):  # noqa: E501
        """Updates a bulletin's image  # noqa: E501

        Required Permissions: System Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bulletin_image_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Id of the bulletin (required)
        :param str image:
        :return: BulletinResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'image']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_bulletin_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_bulletin_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'image' in params:
            local_var_files['image'] = params['image']  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['multipart/form-data'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Bulletins/{id}/image', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BulletinResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.analytics_api import AnalyticsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestAnalyticsApi(unittest.TestCase):
    """AnalyticsApi unit test stubs"""

    def setUp(self):
        self.api = AnalyticsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_analytics_assignment(self):
        """Test case for create_analytics_assignment

        Creates a model assignment on a new analytics group under the specified parent group  # noqa: E501
        """
        pass

    def test_create_analytics_models(self):
        """Test case for create_analytics_models

        Creates an Analytics Model  # noqa: E501
        """
        pass

    def test_delete_analytics_assignment(self):
        """Test case for delete_analytics_assignment

        Deletes the model assignment and the analytics group that holds it  # noqa: E501
        """
        pass

    def test_delete_analytics_model(self):
        """Test case for delete_analytics_model

        Deletes an Analytics Model  # noqa: E501
        """
        pass

    def test_get_analytics_assignment(self):
        """Test case for get_analytics_assignment

        Gets the model assignment  # noqa: E501
        """
        pass

    def test_get_analytics_assignments(self):
        """Test case for get_analytics_assignments

        Gets all model assignments  # noqa: E501
        """
        pass

    def test_get_analytics_logs(self):
        """Test case for get_analytics_logs

        Gets logs for the model  # noqa: E501
        """
        pass

    def test_get_analytics_model(self):
        """Test case for get_analytics_model

        Gets an Analytics Model  # noqa: E501
        """
        pass

    def test_get_analytics_model_source(self):
        """Test case for get_analytics_model_source

        Gets the files associated with an analytics model  # noqa: E501
        """
        pass

    def test_get_analytics_model_template(self):
        """Test case for get_analytics_model_template

        Gets the analytics model template file  # noqa: E501
        """
        pass

    def test_get_analytics_models(self):
        """Test case for get_analytics_models

        Gets Analytics Models  # noqa: E501
        """
        pass

    def test_update_analytics_assignment(self):
        """Test case for update_analytics_assignment

        Updates a model assignment  # noqa: E501
        """
        pass

    def test_update_analytics_model_source(self):
        """Test case for update_analytics_model_source

        Updates the files associated with an analytics model  # noqa: E501
        """
        pass

    def test_update_analytics_model_status(self):
        """Test case for update_analytics_model_status

        Updates the status of the model  # noqa: E501
        """
        pass

    def test_update_analytics_models(self):
        """Test case for update_analytics_models

        Updates an Analytics Model  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AssetUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_paused': 'bool',
        'running_speed_type': 'AssetRunningSpeedType',
        'running_speed_min': 'float',
        'running_speed_max': 'float',
        'running_speed_unit': 'str',
        'running_speed_reference_monitoring_point_id': 'str',
        'running_speed_sensor_role_type': 'SensorRoleTypeCodes',
        'primary_image_file_id': 'str',
        'name': 'str',
        'abbreviation': 'str',
        'supplier': 'str',
        'manufacturer': 'str',
        'model_name': 'str',
        'location_notes': 'str',
        'notes': 'str',
        'generic_input': 'str',
        'is_operator_view': 'bool',
        'type_id': 'int',
        'category_id': 'int',
        'size_id': 'int',
        'criticality_id': 'int',
        'asset_cost': 'float',
        'date_installed': 'datetime',
        'annual_run_time': 'float',
        'lost_production_cost': 'float',
        'overhaul_cost': 'float',
        'power_consumption': 'float',
        'life_expectancy': 'float',
        'unscheduled_downtime': 'float',
        'running_speed_harmonic': 'float'
    }

    attribute_map = {
        'is_paused': 'IsPaused',
        'running_speed_type': 'RunningSpeedType',
        'running_speed_min': 'RunningSpeedMin',
        'running_speed_max': 'RunningSpeedMax',
        'running_speed_unit': 'RunningSpeedUnit',
        'running_speed_reference_monitoring_point_id': 'RunningSpeedReferenceMonitoringPointId',
        'running_speed_sensor_role_type': 'RunningSpeedSensorRoleType',
        'primary_image_file_id': 'PrimaryImageFileId',
        'name': 'Name',
        'abbreviation': 'Abbreviation',
        'supplier': 'Supplier',
        'manufacturer': 'Manufacturer',
        'model_name': 'ModelName',
        'location_notes': 'LocationNotes',
        'notes': 'Notes',
        'generic_input': 'GenericInput',
        'is_operator_view': 'IsOperatorView',
        'type_id': 'TypeId',
        'category_id': 'CategoryId',
        'size_id': 'SizeId',
        'criticality_id': 'CriticalityId',
        'asset_cost': 'AssetCost',
        'date_installed': 'DateInstalled',
        'annual_run_time': 'AnnualRunTime',
        'lost_production_cost': 'LostProductionCost',
        'overhaul_cost': 'OverhaulCost',
        'power_consumption': 'PowerConsumption',
        'life_expectancy': 'LifeExpectancy',
        'unscheduled_downtime': 'UnscheduledDowntime',
        'running_speed_harmonic': 'RunningSpeedHarmonic'
    }

    def __init__(self, is_paused=None, running_speed_type=None, running_speed_min=None, running_speed_max=None, running_speed_unit=None, running_speed_reference_monitoring_point_id=None, running_speed_sensor_role_type=None, primary_image_file_id=None, name=None, abbreviation=None, supplier=None, manufacturer=None, model_name=None, location_notes=None, notes=None, generic_input=None, is_operator_view=None, type_id=None, category_id=None, size_id=None, criticality_id=None, asset_cost=None, date_installed=None, annual_run_time=None, lost_production_cost=None, overhaul_cost=None, power_consumption=None, life_expectancy=None, unscheduled_downtime=None, running_speed_harmonic=None):  # noqa: E501
        """AssetUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._is_paused = None
        self._running_speed_type = None
        self._running_speed_min = None
        self._running_speed_max = None
        self._running_speed_unit = None
        self._running_speed_reference_monitoring_point_id = None
        self._running_speed_sensor_role_type = None
        self._primary_image_file_id = None
        self._name = None
        self._abbreviation = None
        self._supplier = None
        self._manufacturer = None
        self._model_name = None
        self._location_notes = None
        self._notes = None
        self._generic_input = None
        self._is_operator_view = None
        self._type_id = None
        self._category_id = None
        self._size_id = None
        self._criticality_id = None
        self._asset_cost = None
        self._date_installed = None
        self._annual_run_time = None
        self._lost_production_cost = None
        self._overhaul_cost = None
        self._power_consumption = None
        self._life_expectancy = None
        self._unscheduled_downtime = None
        self._running_speed_harmonic = None
        self.discriminator = None
        self.is_paused = is_paused
        self.running_speed_type = running_speed_type
        if running_speed_min is not None:
            self.running_speed_min = running_speed_min
        if running_speed_max is not None:
            self.running_speed_max = running_speed_max
        if running_speed_unit is not None:
            self.running_speed_unit = running_speed_unit
        if running_speed_reference_monitoring_point_id is not None:
            self.running_speed_reference_monitoring_point_id = running_speed_reference_monitoring_point_id
        if running_speed_sensor_role_type is not None:
            self.running_speed_sensor_role_type = running_speed_sensor_role_type
        if primary_image_file_id is not None:
            self.primary_image_file_id = primary_image_file_id
        self.name = name
        if abbreviation is not None:
            self.abbreviation = abbreviation
        if supplier is not None:
            self.supplier = supplier
        if manufacturer is not None:
            self.manufacturer = manufacturer
        if model_name is not None:
            self.model_name = model_name
        if location_notes is not None:
            self.location_notes = location_notes
        if notes is not None:
            self.notes = notes
        if generic_input is not None:
            self.generic_input = generic_input
        self.is_operator_view = is_operator_view
        if type_id is not None:
            self.type_id = type_id
        if category_id is not None:
            self.category_id = category_id
        if size_id is not None:
            self.size_id = size_id
        if criticality_id is not None:
            self.criticality_id = criticality_id
        if asset_cost is not None:
            self.asset_cost = asset_cost
        if date_installed is not None:
            self.date_installed = date_installed
        if annual_run_time is not None:
            self.annual_run_time = annual_run_time
        if lost_production_cost is not None:
            self.lost_production_cost = lost_production_cost
        if overhaul_cost is not None:
            self.overhaul_cost = overhaul_cost
        if power_consumption is not None:
            self.power_consumption = power_consumption
        if life_expectancy is not None:
            self.life_expectancy = life_expectancy
        if unscheduled_downtime is not None:
            self.unscheduled_downtime = unscheduled_downtime
        if running_speed_harmonic is not None:
            self.running_speed_harmonic = running_speed_harmonic

    @property
    def is_paused(self):
        """Gets the is_paused of this AssetUpdateRequest.  # noqa: E501


        :return: The is_paused of this AssetUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this AssetUpdateRequest.


        :param is_paused: The is_paused of this AssetUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def running_speed_type(self):
        """Gets the running_speed_type of this AssetUpdateRequest.  # noqa: E501


        :return: The running_speed_type of this AssetUpdateRequest.  # noqa: E501
        :rtype: AssetRunningSpeedType
        """
        return self._running_speed_type

    @running_speed_type.setter
    def running_speed_type(self, running_speed_type):
        """Sets the running_speed_type of this AssetUpdateRequest.


        :param running_speed_type: The running_speed_type of this AssetUpdateRequest.  # noqa: E501
        :type: AssetRunningSpeedType
        """
        if running_speed_type is None:
            raise ValueError("Invalid value for `running_speed_type`, must not be `None`")  # noqa: E501

        self._running_speed_type = running_speed_type

    @property
    def running_speed_min(self):
        """Gets the running_speed_min of this AssetUpdateRequest.  # noqa: E501


        :return: The running_speed_min of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_min

    @running_speed_min.setter
    def running_speed_min(self, running_speed_min):
        """Sets the running_speed_min of this AssetUpdateRequest.


        :param running_speed_min: The running_speed_min of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._running_speed_min = running_speed_min

    @property
    def running_speed_max(self):
        """Gets the running_speed_max of this AssetUpdateRequest.  # noqa: E501


        :return: The running_speed_max of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_max

    @running_speed_max.setter
    def running_speed_max(self, running_speed_max):
        """Sets the running_speed_max of this AssetUpdateRequest.


        :param running_speed_max: The running_speed_max of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._running_speed_max = running_speed_max

    @property
    def running_speed_unit(self):
        """Gets the running_speed_unit of this AssetUpdateRequest.  # noqa: E501


        :return: The running_speed_unit of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._running_speed_unit

    @running_speed_unit.setter
    def running_speed_unit(self, running_speed_unit):
        """Sets the running_speed_unit of this AssetUpdateRequest.


        :param running_speed_unit: The running_speed_unit of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._running_speed_unit = running_speed_unit

    @property
    def running_speed_reference_monitoring_point_id(self):
        """Gets the running_speed_reference_monitoring_point_id of this AssetUpdateRequest.  # noqa: E501


        :return: The running_speed_reference_monitoring_point_id of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._running_speed_reference_monitoring_point_id

    @running_speed_reference_monitoring_point_id.setter
    def running_speed_reference_monitoring_point_id(self, running_speed_reference_monitoring_point_id):
        """Sets the running_speed_reference_monitoring_point_id of this AssetUpdateRequest.


        :param running_speed_reference_monitoring_point_id: The running_speed_reference_monitoring_point_id of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._running_speed_reference_monitoring_point_id = running_speed_reference_monitoring_point_id

    @property
    def running_speed_sensor_role_type(self):
        """Gets the running_speed_sensor_role_type of this AssetUpdateRequest.  # noqa: E501


        :return: The running_speed_sensor_role_type of this AssetUpdateRequest.  # noqa: E501
        :rtype: SensorRoleTypeCodes
        """
        return self._running_speed_sensor_role_type

    @running_speed_sensor_role_type.setter
    def running_speed_sensor_role_type(self, running_speed_sensor_role_type):
        """Sets the running_speed_sensor_role_type of this AssetUpdateRequest.


        :param running_speed_sensor_role_type: The running_speed_sensor_role_type of this AssetUpdateRequest.  # noqa: E501
        :type: SensorRoleTypeCodes
        """

        self._running_speed_sensor_role_type = running_speed_sensor_role_type

    @property
    def primary_image_file_id(self):
        """Gets the primary_image_file_id of this AssetUpdateRequest.  # noqa: E501


        :return: The primary_image_file_id of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_file_id

    @primary_image_file_id.setter
    def primary_image_file_id(self, primary_image_file_id):
        """Sets the primary_image_file_id of this AssetUpdateRequest.


        :param primary_image_file_id: The primary_image_file_id of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._primary_image_file_id = primary_image_file_id

    @property
    def name(self):
        """Gets the name of this AssetUpdateRequest.  # noqa: E501


        :return: The name of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssetUpdateRequest.


        :param name: The name of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def abbreviation(self):
        """Gets the abbreviation of this AssetUpdateRequest.  # noqa: E501


        :return: The abbreviation of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._abbreviation

    @abbreviation.setter
    def abbreviation(self, abbreviation):
        """Sets the abbreviation of this AssetUpdateRequest.


        :param abbreviation: The abbreviation of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._abbreviation = abbreviation

    @property
    def supplier(self):
        """Gets the supplier of this AssetUpdateRequest.  # noqa: E501


        :return: The supplier of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._supplier

    @supplier.setter
    def supplier(self, supplier):
        """Sets the supplier of this AssetUpdateRequest.


        :param supplier: The supplier of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._supplier = supplier

    @property
    def manufacturer(self):
        """Gets the manufacturer of this AssetUpdateRequest.  # noqa: E501


        :return: The manufacturer of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._manufacturer

    @manufacturer.setter
    def manufacturer(self, manufacturer):
        """Sets the manufacturer of this AssetUpdateRequest.


        :param manufacturer: The manufacturer of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._manufacturer = manufacturer

    @property
    def model_name(self):
        """Gets the model_name of this AssetUpdateRequest.  # noqa: E501


        :return: The model_name of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this AssetUpdateRequest.


        :param model_name: The model_name of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def location_notes(self):
        """Gets the location_notes of this AssetUpdateRequest.  # noqa: E501


        :return: The location_notes of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_notes

    @location_notes.setter
    def location_notes(self, location_notes):
        """Sets the location_notes of this AssetUpdateRequest.


        :param location_notes: The location_notes of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._location_notes = location_notes

    @property
    def notes(self):
        """Gets the notes of this AssetUpdateRequest.  # noqa: E501


        :return: The notes of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this AssetUpdateRequest.


        :param notes: The notes of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def generic_input(self):
        """Gets the generic_input of this AssetUpdateRequest.  # noqa: E501


        :return: The generic_input of this AssetUpdateRequest.  # noqa: E501
        :rtype: str
        """
        return self._generic_input

    @generic_input.setter
    def generic_input(self, generic_input):
        """Sets the generic_input of this AssetUpdateRequest.


        :param generic_input: The generic_input of this AssetUpdateRequest.  # noqa: E501
        :type: str
        """

        self._generic_input = generic_input

    @property
    def is_operator_view(self):
        """Gets the is_operator_view of this AssetUpdateRequest.  # noqa: E501


        :return: The is_operator_view of this AssetUpdateRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_operator_view

    @is_operator_view.setter
    def is_operator_view(self, is_operator_view):
        """Sets the is_operator_view of this AssetUpdateRequest.


        :param is_operator_view: The is_operator_view of this AssetUpdateRequest.  # noqa: E501
        :type: bool
        """
        if is_operator_view is None:
            raise ValueError("Invalid value for `is_operator_view`, must not be `None`")  # noqa: E501

        self._is_operator_view = is_operator_view

    @property
    def type_id(self):
        """Gets the type_id of this AssetUpdateRequest.  # noqa: E501


        :return: The type_id of this AssetUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._type_id

    @type_id.setter
    def type_id(self, type_id):
        """Sets the type_id of this AssetUpdateRequest.


        :param type_id: The type_id of this AssetUpdateRequest.  # noqa: E501
        :type: int
        """

        self._type_id = type_id

    @property
    def category_id(self):
        """Gets the category_id of this AssetUpdateRequest.  # noqa: E501


        :return: The category_id of this AssetUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this AssetUpdateRequest.


        :param category_id: The category_id of this AssetUpdateRequest.  # noqa: E501
        :type: int
        """

        self._category_id = category_id

    @property
    def size_id(self):
        """Gets the size_id of this AssetUpdateRequest.  # noqa: E501


        :return: The size_id of this AssetUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._size_id

    @size_id.setter
    def size_id(self, size_id):
        """Sets the size_id of this AssetUpdateRequest.


        :param size_id: The size_id of this AssetUpdateRequest.  # noqa: E501
        :type: int
        """

        self._size_id = size_id

    @property
    def criticality_id(self):
        """Gets the criticality_id of this AssetUpdateRequest.  # noqa: E501


        :return: The criticality_id of this AssetUpdateRequest.  # noqa: E501
        :rtype: int
        """
        return self._criticality_id

    @criticality_id.setter
    def criticality_id(self, criticality_id):
        """Sets the criticality_id of this AssetUpdateRequest.


        :param criticality_id: The criticality_id of this AssetUpdateRequest.  # noqa: E501
        :type: int
        """

        self._criticality_id = criticality_id

    @property
    def asset_cost(self):
        """Gets the asset_cost of this AssetUpdateRequest.  # noqa: E501


        :return: The asset_cost of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._asset_cost

    @asset_cost.setter
    def asset_cost(self, asset_cost):
        """Sets the asset_cost of this AssetUpdateRequest.


        :param asset_cost: The asset_cost of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._asset_cost = asset_cost

    @property
    def date_installed(self):
        """Gets the date_installed of this AssetUpdateRequest.  # noqa: E501


        :return: The date_installed of this AssetUpdateRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._date_installed

    @date_installed.setter
    def date_installed(self, date_installed):
        """Sets the date_installed of this AssetUpdateRequest.


        :param date_installed: The date_installed of this AssetUpdateRequest.  # noqa: E501
        :type: datetime
        """

        self._date_installed = date_installed

    @property
    def annual_run_time(self):
        """Gets the annual_run_time of this AssetUpdateRequest.  # noqa: E501


        :return: The annual_run_time of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._annual_run_time

    @annual_run_time.setter
    def annual_run_time(self, annual_run_time):
        """Sets the annual_run_time of this AssetUpdateRequest.


        :param annual_run_time: The annual_run_time of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._annual_run_time = annual_run_time

    @property
    def lost_production_cost(self):
        """Gets the lost_production_cost of this AssetUpdateRequest.  # noqa: E501


        :return: The lost_production_cost of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._lost_production_cost

    @lost_production_cost.setter
    def lost_production_cost(self, lost_production_cost):
        """Sets the lost_production_cost of this AssetUpdateRequest.


        :param lost_production_cost: The lost_production_cost of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._lost_production_cost = lost_production_cost

    @property
    def overhaul_cost(self):
        """Gets the overhaul_cost of this AssetUpdateRequest.  # noqa: E501


        :return: The overhaul_cost of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._overhaul_cost

    @overhaul_cost.setter
    def overhaul_cost(self, overhaul_cost):
        """Sets the overhaul_cost of this AssetUpdateRequest.


        :param overhaul_cost: The overhaul_cost of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._overhaul_cost = overhaul_cost

    @property
    def power_consumption(self):
        """Gets the power_consumption of this AssetUpdateRequest.  # noqa: E501


        :return: The power_consumption of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._power_consumption

    @power_consumption.setter
    def power_consumption(self, power_consumption):
        """Sets the power_consumption of this AssetUpdateRequest.


        :param power_consumption: The power_consumption of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._power_consumption = power_consumption

    @property
    def life_expectancy(self):
        """Gets the life_expectancy of this AssetUpdateRequest.  # noqa: E501


        :return: The life_expectancy of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._life_expectancy

    @life_expectancy.setter
    def life_expectancy(self, life_expectancy):
        """Sets the life_expectancy of this AssetUpdateRequest.


        :param life_expectancy: The life_expectancy of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._life_expectancy = life_expectancy

    @property
    def unscheduled_downtime(self):
        """Gets the unscheduled_downtime of this AssetUpdateRequest.  # noqa: E501


        :return: The unscheduled_downtime of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._unscheduled_downtime

    @unscheduled_downtime.setter
    def unscheduled_downtime(self, unscheduled_downtime):
        """Sets the unscheduled_downtime of this AssetUpdateRequest.


        :param unscheduled_downtime: The unscheduled_downtime of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._unscheduled_downtime = unscheduled_downtime

    @property
    def running_speed_harmonic(self):
        """Gets the running_speed_harmonic of this AssetUpdateRequest.  # noqa: E501


        :return: The running_speed_harmonic of this AssetUpdateRequest.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_harmonic

    @running_speed_harmonic.setter
    def running_speed_harmonic(self, running_speed_harmonic):
        """Sets the running_speed_harmonic of this AssetUpdateRequest.


        :param running_speed_harmonic: The running_speed_harmonic of this AssetUpdateRequest.  # noqa: E501
        :type: float
        """

        self._running_speed_harmonic = running_speed_harmonic

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AssetUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventRelationshipCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'relationship_type': 'ActivityEventRelationshipType',
        'from_activity_event_id': 'str',
        'to_activity_event_id': 'str'
    }

    attribute_map = {
        'relationship_type': 'RelationshipType',
        'from_activity_event_id': 'FromActivityEventId',
        'to_activity_event_id': 'ToActivityEventId'
    }

    def __init__(self, relationship_type=None, from_activity_event_id=None, to_activity_event_id=None):  # noqa: E501
        """ActivityEventRelationshipCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._relationship_type = None
        self._from_activity_event_id = None
        self._to_activity_event_id = None
        self.discriminator = None
        self.relationship_type = relationship_type
        self.from_activity_event_id = from_activity_event_id
        self.to_activity_event_id = to_activity_event_id

    @property
    def relationship_type(self):
        """Gets the relationship_type of this ActivityEventRelationshipCreateRequest.  # noqa: E501


        :return: The relationship_type of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :rtype: ActivityEventRelationshipType
        """
        return self._relationship_type

    @relationship_type.setter
    def relationship_type(self, relationship_type):
        """Sets the relationship_type of this ActivityEventRelationshipCreateRequest.


        :param relationship_type: The relationship_type of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :type: ActivityEventRelationshipType
        """
        if relationship_type is None:
            raise ValueError("Invalid value for `relationship_type`, must not be `None`")  # noqa: E501

        self._relationship_type = relationship_type

    @property
    def from_activity_event_id(self):
        """Gets the from_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501


        :return: The from_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._from_activity_event_id

    @from_activity_event_id.setter
    def from_activity_event_id(self, from_activity_event_id):
        """Sets the from_activity_event_id of this ActivityEventRelationshipCreateRequest.


        :param from_activity_event_id: The from_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :type: str
        """
        if from_activity_event_id is None:
            raise ValueError("Invalid value for `from_activity_event_id`, must not be `None`")  # noqa: E501

        self._from_activity_event_id = from_activity_event_id

    @property
    def to_activity_event_id(self):
        """Gets the to_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501


        :return: The to_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._to_activity_event_id

    @to_activity_event_id.setter
    def to_activity_event_id(self, to_activity_event_id):
        """Sets the to_activity_event_id of this ActivityEventRelationshipCreateRequest.


        :param to_activity_event_id: The to_activity_event_id of this ActivityEventRelationshipCreateRequest.  # noqa: E501
        :type: str
        """
        if to_activity_event_id is None:
            raise ValueError("Invalid value for `to_activity_event_id`, must not be `None`")  # noqa: E501

        self._to_activity_event_id = to_activity_event_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventRelationshipCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventRelationshipCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
